@@ -1,4 +1,5 @@
 """A collection of tools to gather and analyze knowledge from projects' repositories."""
 
-__title__ = "src-ops-metrics"
-__version__ = "2.0.1"
+
+__title__ = "srcopsmetrics"
+__version__ = "2.9.1"
